SWH-loader-core
===============

The Software Heritage Core Loader is a low-level loading utilities and
helpers used by other loaders.

The main entry points are classes:
- :class:`swh.loader.core.loader.SWHLoader` for stateful loaders
- :class:`swh.loader.core.loader.SWHStatelessLoader` for stateless loaders
